==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/PortSelectorFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PortSelectorFluent<A extends PortSelectorFluent<A>> extends BaseFluent<A>{
  public PortSelectorFluent() {
  }
  public PortSelectorFluent(PortSelector instance) {
    instance = (instance != null ? instance : new PortSelector());

    if (instance != null) {
      this.withNumber(instance.getNumber());
      this.withNumber(instance.getNumber());
    }
  }
  private Integer number;
  public Integer getNumber() {
    return this.number;
  }
  public A withNumber(Integer number) {
    this.number=number; return (A) this;
  }
  public boolean hasNumber() {
    return this.number != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortSelectorFluent that = (PortSelectorFluent) o;
    if (!java.util.Objects.equals(number, that.number)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(number,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (number != null) { sb.append("number:"); sb.append(number); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/PortSelectorFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PortSelectorFluent<A extends PortSelectorFluent<A>> extends BaseFluent<A>{
  public PortSelectorFluent() {
  }
  
  public PortSelectorFluent(PortSelector instance) {
    this.copyInstance(instance);
  }
  private Integer number;
  
  protected void copyInstance(PortSelector instance) {
    instance = (instance != null ? instance : new PortSelector());
  
    if (instance != null) {
        this.withNumber(instance.getNumber());
        this.withNumber(instance.getNumber());
      }
  }
  
  public Integer getNumber() {
    return this.number;
  }
  
  public A withNumber(Integer number) {
    this.number=number; return (A) this;
  }
  
  public boolean hasNumber() {
    return this.number != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PortSelectorFluent that = (PortSelectorFluent) o;
    if (!java.util.Objects.equals(number, that.number)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(number,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (number != null) { sb.append("number:"); sb.append(number); }
    sb.append("}");
    return sb.toString();
  }
  

}
